@@ -1,21 +1,22 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
  *    GDMcommunication routines
  *    (c)2001 Queen of England, (c)2002,2003 George Lebl
- *    
+ *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation; either version 2 of the License, or
  *    (at your option) any later version.
- *   
+ *
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
- *   
+ *
  *    You should have received a copy of the GNU General Public License
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- * 
+ *
  */
 
 #include "config.h"
@@ -35,32 +36,19 @@
 #include <sys/un.h>
 #include <errno.h>
 
-#include "vicious.h"
-
 #include "gdm.h"
 #include "gdmcommon.h"
 #include "gdmcomm.h"
 #include "gdmconfig.h"
 
+#include "gdm-common.h"
+#include "gdm-socket-protocol.h"
+#include "gdm-daemon-config-keys.h"
+
 static gboolean bulk_acs = FALSE;
-static gboolean debug    = FALSE;
 static gboolean quiet    = FALSE;
 static int      num_cmds = 0;
 
-/*
- * Note, in this function we have to call gdm_common_error instead
- * of gdm_common_debug, since gdm_common_debug accesses the
- * GDM_KEY_DEBUG which can cause a sockets connection to get the
- * config data, causing an infinite loop.  This is why clients must
- * call the gdmcomm_set_debug function to turn on debug for these
- * functions.  
- */
-void
-gdmcomm_set_debug (gboolean enable)
-{
-	debug = enable;
-}
-
 /*
  * Normally errors are printed.  Setting quiet to TRUE turns off
  * display of error messages.
@@ -82,9 +70,7 @@ do_command (int fd, const char *command, gboolean get_response)
 	void (*old_handler)(int);
 #endif
 
-	if (debug) {
-		gdm_common_error ("Sending command: '%s'", command);
-	}
+        gdm_common_debug ("Sending command: '%s'", command);
 
 	cstr = g_strdup_printf ("%s\n", command);
 
@@ -101,7 +87,7 @@ do_command (int fd, const char *command, gboolean get_response)
 
 	if (ret < 0) {
 		if ( !quiet)
-			gdm_common_error ("Command failed, no data returned");
+			gdm_common_debug ("Command failed, no data returned");
 		return NULL;
 	}
 
@@ -115,8 +101,7 @@ do_command (int fd, const char *command, gboolean get_response)
 		g_string_append_c (str, buf[0]);
 	}
 
-	if (debug)
-		gdm_common_error ("  Got response: '%s'", str->str);
+        gdm_common_debug ("  Got response: '%s'", str->str);
 
 	cstr = str->str;
 	g_string_free (str, FALSE);
@@ -134,7 +119,7 @@ do_command (int fd, const char *command, gboolean get_response)
 	if (ve_string_empty (cstr) ||
 	    strcmp (ve_sure_string (cstr), "ERROR 200 Too many messages") == 0) {
 		if ( !quiet)
-			gdm_common_error ("Command failed, daemon busy.");
+			gdm_common_debug ("Command failed, daemon busy.");
 		g_free (cstr);
 		return NULL;
 	}
@@ -180,23 +165,22 @@ gdmcomm_call_gdm_real (const char *command,
          * and reopen.  Subtract 1 to allow the "CLOSE" to get through.
          */
 	if (num_cmds == (GDM_SUP_MAX_MESSAGES - 1)) {
-	   if (debug)
-		gdm_common_error ("  Closing and reopening connection.");
-	   do_command (comm_fd, GDM_SUP_CLOSE, FALSE);
-	   VE_IGNORE_EINTR (close (comm_fd));
-	   comm_fd  = 0;
-	   num_cmds = 0;
+		gdm_common_debug ("  Closing and reopening connection.");
+		do_command (comm_fd, GDM_SUP_CLOSE, FALSE);
+		VE_IGNORE_EINTR (close (comm_fd));
+		comm_fd  = 0;
+		num_cmds = 0;
 	}
 
 	if (tries <= 0) {
 		if ( !quiet)
-			gdm_common_error ("  Command failed %d times, aborting.", try_start);
+			gdm_common_debug ("  Command failed %d times, aborting.", try_start);
 		return NULL;
 	}
 
 	if (!quiet && tries != try_start) {
-		gdm_common_error ("  Trying failed command again.  Try %d of %d.",
-			(try_start - tries + 1), try_start);
+		gdm_common_debug ("  Trying failed command again.  Try %d of %d.",
+				  (try_start - tries + 1), try_start);
 	}
 
 	if (comm_fd <= 0) {
@@ -206,7 +190,7 @@ gdmcomm_call_gdm_real (const char *command,
 		comm_fd = socket (AF_UNIX, SOCK_STREAM, 0);
 		if (comm_fd < 0) {
 			if ( !quiet)
-				gdm_common_error ("  Failed to open socket");
+				gdm_common_debug ("  Failed to open socket");
 
 			return gdmcomm_call_gdm_real (command, auth_cookie, min_version, tries - 1, try_start);
 		}
@@ -234,17 +218,17 @@ gdmcomm_call_gdm_real (const char *command,
 				 */
 				if (tries > 1) {
 					if ( !quiet)
-						gdm_common_error ("  Failed to connect to socket, sleep 1 second and retry");
+						gdm_common_debug ("  Failed to connect to socket, sleep 1 second and retry");
 					sleep (1);
 				}
 			} else {
 				if ( !quiet)
-					gdm_common_error ("  Failed to connect to socket, not sleeping");
+					gdm_common_debug ("  Failed to connect to socket, not sleeping");
 			}
 			VE_IGNORE_EINTR (close (comm_fd));
 			comm_fd = 0;
 			return gdmcomm_call_gdm_real (command, auth_cookie,
-				min_version, tries - 1, try_start);
+						      min_version, tries - 1, try_start);
 		}
 
 		/*
@@ -259,15 +243,15 @@ gdmcomm_call_gdm_real (const char *command,
 		ret = do_command (comm_fd, GDM_SUP_VERSION, TRUE);
 		if (ret == NULL) {
 			if ( !quiet)
-				gdm_common_error ("  Version check failed");
+				gdm_common_debug ("  Version check failed");
 			VE_IGNORE_EINTR (close (comm_fd));
 			comm_fd = 0;
 			return gdmcomm_call_gdm_real (command, auth_cookie,
-				min_version, tries - 1, try_start);
+						      min_version, tries - 1, try_start);
 		}
 		if (strncmp (ret, "GDM ", strlen ("GDM ")) != 0) {
 			if ( !quiet)
-				gdm_common_error ("  Version check failed, bad name");
+				gdm_common_debug ("  Version check failed, bad name");
 
 			g_free (ret);
 			do_command (comm_fd, GDM_SUP_CLOSE, FALSE);
@@ -277,7 +261,7 @@ gdmcomm_call_gdm_real (const char *command,
 		}
 		if ( ! version_ok_p (&ret[4], min_version)) {
 			if ( !quiet)
-				gdm_common_error ("  Version check failed, bad version");
+				gdm_common_debug ("  Version check failed, bad version");
 			g_free (ret);
 			do_command (comm_fd, GDM_SUP_CLOSE, FALSE);
 			VE_IGNORE_EINTR (close (comm_fd));
@@ -297,12 +281,12 @@ gdmcomm_call_gdm_real (const char *command,
 			VE_IGNORE_EINTR (close (comm_fd));
 			comm_fd = 0;
 			return gdmcomm_call_gdm_real (command, auth_cookie,
-				min_version, tries - 1, try_start);
+						      min_version, tries - 1, try_start);
 		}
 		/* not auth'ed */
 		if (strcmp (ve_sure_string (ret), "OK") != 0) {
 			if ( !quiet)
-				gdm_common_error ("  Error, auth check failed");
+				gdm_common_debug ("  Error, auth check failed");
 			do_command (comm_fd, GDM_SUP_CLOSE, FALSE);
 			VE_IGNORE_EINTR (close (comm_fd));
 			comm_fd = 0;
@@ -317,7 +301,7 @@ gdmcomm_call_gdm_real (const char *command,
 		VE_IGNORE_EINTR (close (comm_fd));
 		comm_fd = 0;
 		return gdmcomm_call_gdm_real (command, auth_cookie,
-			min_version, tries - 1, try_start);
+					      min_version, tries - 1, try_start);
 	}
 
 	/*
@@ -342,13 +326,13 @@ gdmcomm_call_gdm_real (const char *command,
 
 char *
 gdmcomm_call_gdm (const char *command, const char * auth_cookie,
-	const char *min_version, int tries)
+		  const char *min_version, int tries)
 {
 
 	char *retstr;
 
 	retstr = gdmcomm_call_gdm_real (command, auth_cookie, min_version,
-		tries, tries);
+					tries, tries);
 
 	/*
 	 * Disallow sleeping on future calls if it failed to connect.
@@ -583,17 +567,43 @@ gdmcomm_get_auth_cookie (void)
 	return cookie;
 }
 
+static GtkWidget *
+hig_dialog_new (GtkWindow      *parent,
+		GtkDialogFlags flags,
+		GtkMessageType type,
+		GtkButtonsType buttons,
+		const gchar    *primary_message,
+		const gchar    *secondary_message)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+		                         GTK_DIALOG_DESTROY_WITH_PARENT,
+		                         type,
+		                         buttons,
+		                         "%s", primary_message);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		                                  "%s", secondary_message);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+
+  	return dialog;
+}
+
 gboolean
 gdmcomm_check (gboolean show_dialog)
 {
 	GtkWidget *dialog;
 	FILE *fp = NULL;
 	long pid;
-	char *pidfile;
+	const char *pidfile;
 	struct stat s;
 	int statret;
 
-	pidfile = gdm_config_get_string (GDM_KEY_PID_FILE);
+	pidfile = GDM_PID_FILE;
 
 	pid = 0;
 	if (pidfile != NULL)
@@ -611,19 +621,18 @@ gdmcomm_check (gboolean show_dialog)
 	    (kill (pid, 0) < 0 &&
 	     errno != EPERM)) {
 		if (show_dialog) {
-			dialog = ve_hig_dialog_new
-				(NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_WARNING,
-				 GTK_BUTTONS_OK,
-				 _("GDM (The GNOME Display Manager) "
-				   "is not running."),
-				 _("You might in fact be using a different "
-				   "display manager, such as KDM "
-				   "(KDE Display Manager) or xdm. "
-				   "If you still wish to use this feature, "
-				   "either start GDM yourself or ask your "
-				   "system administrator to start GDM."));
+			dialog = hig_dialog_new (NULL /* parent */,
+                                                 GTK_DIALOG_MODAL /* flags */,
+                                                 GTK_MESSAGE_WARNING,
+                                                 GTK_BUTTONS_OK,
+                                                 _("GDM (GNOME Display Manager) is not "
+                                                   "running."),
+                                                 _("You might be using a different display "
+                                                   "manager, such as KDM (KDE Display "
+                                                   "Manager), CDE login (dtlogin), or xdm. "
+                                                   "If you wish to use this feature, then "
+                                                   "your system will need to be configured "
+                                                   "to use GDM instead."));
 
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
@@ -637,15 +646,14 @@ gdmcomm_check (gboolean show_dialog)
 	    s.st_uid != 0 ||
 	    g_access (GDM_SUP_SOCKET, R_OK|W_OK) != 0) {
 		if (show_dialog) {
-			dialog = ve_hig_dialog_new
-				(NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_WARNING,
-				 GTK_BUTTONS_OK,
-				 _("Cannot communicate with GDM "
-				   "(The GNOME Display Manager)"),
-				 _("Perhaps you have an old version "
-				   "of GDM running."));
+			dialog = hig_dialog_new (NULL /* parent */,
+                                                 GTK_DIALOG_MODAL /* flags */,
+                                                 GTK_MESSAGE_WARNING,
+                                                 GTK_BUTTONS_OK,
+                                                 _("Cannot communicate with GDM "
+                                                   "(The GNOME Display Manager)"),
+                                                 _("Perhaps you have an old version "
+                                                   "of GDM running."));
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -676,13 +684,13 @@ gdmcomm_get_error_message (const char *ret, gboolean use_xnest)
 	} else if (strncmp (ret, "ERROR 4 ", strlen ("ERROR 4 ")) == 0) {
 		return _("Too many X sessions running.");
 	} else if (strncmp (ret, "ERROR 5 ", strlen ("ERROR 5 ")) == 0) {
-		return _("The nested X server (Xnest) cannot connect to "
-			 "your current X server.  You may be missing an "
+		return _("The nested X server cannot connect to your "
+			 "current X server.  You may be missing an "
 			 "X authorization file.");
 	} else if (strncmp (ret, "ERROR 6 ", strlen ("ERROR 6 ")) == 0) {
 		if (use_xnest)
-			return _("The nested X server (Xnest) is not "
-				 "available, or GDM is badly configured.\n"
+			return _("The nested X server is not available, "
+				 "or GDM is badly configured.\n"
 				 "Please install the Xnest package in "
 				 "order to use the nested login.");
 		else
