@@ -159,14 +159,20 @@ make_menubar (void)
 	menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (w), menu);
 
-	w = gtk_menu_item_new_with_mnemonic (_("Select _Language..."));
+	w = gtk_image_menu_item_new_with_mnemonic (_("Select _Language..."));
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w), 
+		gtk_image_new_from_icon_name ("preferences-desktop-locale", GTK_ICON_SIZE_MENU));
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 	gtk_widget_show (GTK_WIDGET (w));
 	g_signal_connect (G_OBJECT (w), "activate",
 			  G_CALLBACK (activate_button),
 			  "language_button");
 
-	w = gtk_menu_item_new_with_mnemonic (_("Select _Session..."));
+	w = gtk_image_menu_item_new_with_mnemonic (_("Select _Session..."));
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w), 
+		gtk_image_new_from_icon_name ("user-desktop", GTK_ICON_SIZE_MENU));
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 	gtk_widget_show (GTK_WIDGET (w));
 	g_signal_connect (G_OBJECT (w), "activate",
@@ -180,9 +186,13 @@ make_menubar (void)
 	 * flexi, even if not local (non-local xnest).  and Disconnect
 	 * only for xdmcp */
 	if ( ! ve_string_empty (g_getenv ("GDM_FLEXI_SERVER"))) {
-		w = gtk_menu_item_new_with_mnemonic (_("_Quit"));
+		w = gtk_image_menu_item_new_with_mnemonic (_("_Quit"));
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w), 
+			gtk_image_new_from_icon_name ("system-log-out", GTK_ICON_SIZE_MENU));
 	} else if (ve_string_empty (g_getenv ("GDM_IS_LOCAL"))) {
-		w = gtk_menu_item_new_with_mnemonic (_("D_isconnect"));
+		w = gtk_image_menu_item_new_with_mnemonic (_("D_isconnect"));
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w), 
+			gtk_image_new_from_icon_name ("system-log-out", GTK_ICON_SIZE_MENU));
 	} else {
 		w = NULL;
 	}
@@ -458,6 +468,8 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
       gtk_entry_set_invisible_char (GTK_ENTRY (entry), 0);
     else if (gdm_config_get_bool (GDM_KEY_ENTRY_CIRCLES))
       gtk_entry_set_invisible_char (GTK_ENTRY (entry), 0x25cf);
+    else
+	    gtk_entry_set_invisible_char (GTK_ENTRY (entry), '*');
 
     gtk_widget_modify_font (entry, item->data.text.fonts[GREETER_ITEM_STATE_NORMAL]);
 
@@ -469,11 +481,11 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
 	     * should probably be done in the pam item setup thingie.
 	     * but this is really widget kind of thing.  I dunno where
 	     * this belongs but it's a hack here. */
-	    GtkWidget *menubar = make_menubar ();
+	    item->data.text.menubar = make_menubar ();
 
 	    gnome_canvas_item_new (gnome_canvas_root (GNOME_CANVAS (canvas)),
 				   GNOME_TYPE_CANVAS_WIDGET,
-				   "widget", menubar,
+				   "widget", item->data.text.menubar,
 				   "x", (double)x1,
 				   "y", (double)y1,
 				   "height", (double)rect.height,
@@ -482,7 +494,7 @@ greeter_item_create_canvas_item (GreeterItemInfo *item)
 
 	    greeter_item_register_action_callback ("options_button",
 						   (ActionFunc)greeter_options_handler,
-						   menubar);
+						   item->data.text.menubar);
 	    
 	    /* Here add a tooltip, so that the user knows about F10 */
 	    tooltips = gtk_tooltips_new ();
